@@ -13,11 +13,11 @@ from lxml.etree import XMLParser, parse, fromstring, Comment, HTMLParser
 from xmldt.element import Element, toxml
 import sys
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 __docformat__ = 'markdown'
 
 
-class XMLDT:
+class XmlDt:
 
     @classmethod
     def tag(cls, name):
@@ -35,15 +35,14 @@ class XMLDT:
         self._strip = strip
         self._empty = empty
         self._types = getattr(self, "_types", {})
-        # self._sem = {}
         self._alias = {
             method.has_alias: method for method in {
                 getattr(self, name) for name in dir(self)
                 if callable(getattr(self, name)) and hasattr(getattr(self, name), "has_alias")}}
 
     def __new__(cls, xml=None, filename=None, strip=False, empty=False, html=False):
-        ## nao gosto, mas funciona
-        self = super(XMLDT, cls).__new__(cls)
+        # nao gosto, mas funciona
+        self = super(XmlDt, cls).__new__(cls)
         self.__init__(strip=strip, empty=empty, html=html)
 
         if filename is not None or xml is not None:
@@ -89,8 +88,6 @@ class XMLDT:
             comment = self.__comment__(element.text)
             return comment
         else:
-            self._path.append(Element(element.tag, {**element.attrib}, None, self))
-
             if element.tag in self._alias:
                 tag_handler = self._alias[element.tag]
             else:
@@ -100,24 +97,27 @@ class XMLDT:
 
             tag_type = self._types.get(element.tag, "string")
 
-            if tag_type == "zero":  ## ignore and skip children
+            if tag_type == "zero":  # ignore and skip children
                 return ""
 
+            # add to path only if required
+            self._path.append(Element(element.tag, {**element.attrib}, None, self))
+
             # given an element, process children, returning a list of pairs
-            contents = self._dt(element)      ### not zero:
+            contents = self._dt(element)      # not zero:
             elem = self._path.pop()
 
-            if tag_type == "string":           ### string (default)
-                c_list = [ele for t, ele in contents if ele]    #### FIXME?? Caso do 0 ???
+            if tag_type == "string":
+                c_list = [ele for t, ele in contents if ele]   # FIXME?? Caso do 0 ???
                 elem.c = self.__join__(c_list)
 
-            elif tag_type == "list":           ###  FIXME list
+            elif tag_type == "list":
                 elem.c = [e for t, e in contents]
 
-            elif tag_type == "map":            ###  FIXME map
+            elif tag_type == "map":
                 elem.c = {t: e for t, e in contents}
 
-            elif tag_type == "mmap":           ###  FIXME mmap
+            elif tag_type == "mmap":
                 raux = {}
                 for t, e in contents:
                     if t in raux:
@@ -126,29 +126,53 @@ class XMLDT:
                         raux[t] = [e]
                 elem.c = raux
 
-            else:                              ### this should never happen
-                elem.c = contents
+            else:
+                raise Exception(f"Element type not recognized: {tag_type}")
 
             return tag_handler(elem)
 
-    def _dt(self, tree):   ### FIXME help, não entendo bem esta árvore.
-        children = []          ### agora retorna lista de pares (tag, conte)*
+    def _dt(self, tree):
+        children = []    # agora retorna lista de pares (tag, conte)*
         if tree.text:
             r = self.__pcdata__(tree.text)
-            if r:   #### FIXME ?? Caso do 0 ???
+            if r:  # should we check for None or "" ?
                 children.append(("-pcdata", r))
 
         for child in tree:
             children.append((child.tag, self._recurse_node(child)))
             if child.tail:
                 r = self.__pcdata__(child.tail)
-                if r:   #### FIXME ?? Caso do 0 ???
+                if r:  # should we check for None or "" ?
                     children.append(("-pcdata", r))
         return children
 
     def __join__(self, child):
         return str.join("", [str(x) for x in child])
 
-    @property
+    def __getitem__(self, item):
+        dt = {
+            "path": self._path,
+            "father": self._father,
+            "gfather": self._gfather,
+            "root": self._root,
+            "in_context": lambda: lambda x: self._in_context(x)  # lovely!
+        }
+        if item in dt:
+            return dt[item]()
+        else:
+            return None
+
+    def _in_context(self, tag):
+        return len([e for e in self._path if e.tag == tag]) > 0
+
     def path(self):
         return self._path
+
+    def _father(self):
+        return None if len(self._path) < 1 else self._path[-1]
+
+    def _gfather(self):
+        return None if len(self._path) < 2 else self._path[-2]
+
+    def _root(self):
+        return None if len(self._path) < 1 else self._path[0]
