@@ -1,3 +1,5 @@
+import sys
+
 
 def toxml(tag, v, *cs):
     tag = tag 
@@ -92,16 +94,16 @@ class Element:
             v = self._attributes
         ats = str.join("", [f' {a}="{b}"' for a, b in v.items()])
         res = f"<{tag}{ats}"
-        if c:
-            if c is not None and len(c) > 0:
-                res += f">{c}</{tag}>"
-            else:
-                res += "/>"
+
+        if c is not None and len(c) > 0:
+            res += f">{c}</{tag}>"
+        elif c == "":      # allow to force an empty element. None can't be used, else following code is never called
+            res += "/>"
+        elif self.c is not None and len(self.c) > 0:
+            res += f">{self.c}</{tag}>"
         else:
-            if self.c is not None and len(self.c) > 0:
-                res += f">{self.c}</{tag}>"
-            else:
-                res += "/>"
+            res += "/>"
+
         return res
 
     @property
@@ -110,8 +112,16 @@ class Element:
 
     @property
     def father(self):
-        return None if self._dt is None or len(self._dt.path) < 1 else self._dt.path[-1]
+        return None if self._dt is None else self._dt["father"]
 
     @property
     def gfather(self):
-        return None if self._dt is None or len(self._dt.path) < 2 else self._dt.path[-2]
+        return None if self._dt is None else self._dt["gfather"]
+
+    @property
+    def root(self):
+        return None if self._dt is None else self._dt["root"]
+
+    def in_context(self, tag):
+        return None if self._dt is None else self._dt["in_context"](tag)
+
