@@ -1,17 +1,17 @@
 import sys
 
-from xmldt import XMLDT
+from xmldt import XmlDt
 import argparse
 import re
 
 
 def build_skel(filename, name="DTSkel"):
     data = Skel(filename=filename)
-    code = [f"""from xmldt import XMLDT
+    code = [f"""from xmldt import XmlDt
 import sys
 
 
-class {name} (XMLDT):
+class {name} (XmlDt):
 
     def __default__(self, element):
           return f"[tag: {{element.tag}}, contents: {{element.contents}}]"
@@ -20,7 +20,7 @@ class {name} (XMLDT):
         method = re.sub("[.]", "_", tag)
         attr_count = str.join(" ", [f"{a}: {data[tag][a]}" for a in data[tag].keys() if a != ":count"])
         if method != tag:
-            code.append(f"""    # @XMLDT.tag("{tag}")""")
+            code.append(f"""    # @XmlDt.tag("{tag}")""")
         code.append(f"""    # def {method}(self, e): return e.tag # {data[tag][":count"]} occs   {attr_count}\n\n""")
     code.append(f"""
     
@@ -41,9 +41,9 @@ def build_skel_jj(files, name="proc"):
         skel(filename=filename)
     print(
 f"""#!/usr/bin/python3
-from xmldt import XMLDT, toxml
+from xmldt import XmlDt, toxml
 import sys
-class {name} (XMLDT):
+class {name} (XmlDt):
     pass
 
     # def __default__(s, e): 
@@ -76,7 +76,7 @@ def ensurepath(seq,path):
         if t not in seq:
             seq.append(t)
 
-class Skeljj (XMLDT):
+class Skeljj (XmlDt):
 
     data={}              ## tag → (attr | # → int)
     ans={}     ## ansesters tag → tag-path  (of first oco)
@@ -118,7 +118,7 @@ class Skeljj (XMLDT):
                 self.data[e.tag][key] += 1
 
 
-class Skel (XMLDT):
+class Skel (XmlDt):
 
     data = {}
 
